iamai.adapter.red package
=========================

Submodules
----------

.. toctree::
   :maxdepth: 4

   iamai.adapter.red.config
   iamai.adapter.red.event

Module contents
---------------

.. automodule:: iamai.adapter.red
   :members:
   :undoc-members:
   :show-inheritance:
